jk_smallgraph
==========

Introduction
------------

This python module is a directed graph implementation where each node and edges is represented as an individual object.

This implementation is not intended to represent large graphs. For this purpose, this implementation may not
be good enough. This is not the purpose of this module. This module provides objects for nodes and edges for
you to attach data to. The focus is on intuitive representation and management of your data,
not on maximum possible performance.

Information about this module can be found here:

* [github.org](https://github.com/jkpubsrc/....)
* [pypi.python.org](https://pypi.python.org/pypi/jk_smallgraph)

Why this module?
----------------

...

Limitations of this module
--------------------------

...

How to use this module
----------------------

### Import this module

Please include this module into your application using the following code:

```python
import jk_smallgraph
```

...

Contact Information
-------------------

* Jürgen Knauth: pubsrc@binary-overflow.de

License
-------

This software is provided under the following license:

* Apache Software License 2.0



